# rapidata.api-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The `rapidata.api_client` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1
- Package version: 1.0.0
- Generator version: 7.9.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.25.3, < 3.0.0
* python-dateutil >= 2.8.2
* pydantic >= 2
* typing-extensions >= 4.7.1

## Getting Started

In your own code, to use this library to connect and interact with rapidata.api-client,
you can run the following:

```python

import rapidata.api_client
from rapidata.api_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = rapidata.api_client.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: bearer
configuration.api_key['bearer'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['bearer'] = 'Bearer'


# Enter a context with an instance of the API client
with rapidata.api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = rapidata.api_client.BenchmarkApi(api_client)
    benchmark_id = 'benchmark_id_example' # str | 

    try:
        # Deletes a single benchmark.
        api_instance.benchmark_benchmark_id_delete(benchmark_id)
    except ApiException as e:
        print("Exception when calling BenchmarkApi->benchmark_benchmark_id_delete: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*BenchmarkApi* | [**benchmark_benchmark_id_delete**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_delete) | **DELETE** /benchmark/{benchmarkId} | Deletes a single benchmark.
*BenchmarkApi* | [**benchmark_benchmark_id_get**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_get) | **GET** /benchmark/{benchmarkId} | Returns a single benchmark by its ID.
*BenchmarkApi* | [**benchmark_benchmark_id_name_put**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_name_put) | **PUT** /benchmark/{benchmarkId}/name | Updates the name of a benchmark.
*BenchmarkApi* | [**benchmark_benchmark_id_participant_participant_id_delete**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_participant_participant_id_delete) | **DELETE** /benchmark/{benchmarkId}/participant/{participantId} | Deletes a participant on a benchmark.
*BenchmarkApi* | [**benchmark_benchmark_id_participant_participant_id_get**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_participant_participant_id_get) | **GET** /benchmark/{benchmarkId}/participant/{participantId} | Gets a participant by it&#39;s Id.
*BenchmarkApi* | [**benchmark_benchmark_id_participants_get**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_participants_get) | **GET** /benchmark/{benchmarkId}/participants | Query all participants within a benchmark
*BenchmarkApi* | [**benchmark_benchmark_id_participants_participant_id_disable_post**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_participants_participant_id_disable_post) | **POST** /benchmark/{benchmarkId}/participants/{participantId}/disable | This endpoint disables a participant in a benchmark. this means that the participant will no longer actively be matched up against other participants and not collect further results. It will still be visible in the leaderboard.
*BenchmarkApi* | [**benchmark_benchmark_id_participants_participant_id_submit_post**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_participants_participant_id_submit_post) | **POST** /benchmark/{benchmarkId}/participants/{participantId}/submit | Submits a participant to a benchmark.
*BenchmarkApi* | [**benchmark_benchmark_id_participants_post**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_participants_post) | **POST** /benchmark/{benchmarkId}/participants | Creates a participant in a benchmark.
*BenchmarkApi* | [**benchmark_benchmark_id_prompt_post**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_prompt_post) | **POST** /benchmark/{benchmarkId}/prompt | Adds a new prompt to a benchmark.
*BenchmarkApi* | [**benchmark_benchmark_id_prompts_get**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_benchmark_id_prompts_get) | **GET** /benchmark/{benchmarkId}/prompts | Returns the paged prompts of a benchmark by its ID.
*BenchmarkApi* | [**benchmark_post**](rapidata/api_client/docs/BenchmarkApi.md#benchmark_post) | **POST** /benchmark | Creates a benchmark
*BenchmarkApi* | [**benchmarks_get**](rapidata/api_client/docs/BenchmarkApi.md#benchmarks_get) | **GET** /benchmarks | Queries all benchmarks of the user.
*CampaignApi* | [**campaign_boost_status_get**](rapidata/api_client/docs/CampaignApi.md#campaign_boost_status_get) | **GET** /campaign/boost/status | Gets the status of the boost.
*CampaignApi* | [**campaign_campaign_id_pause_post**](rapidata/api_client/docs/CampaignApi.md#campaign_campaign_id_pause_post) | **POST** /campaign/{campaignId}/pause | Pauses a campaign.
*CampaignApi* | [**campaign_campaign_id_resume_post**](rapidata/api_client/docs/CampaignApi.md#campaign_campaign_id_resume_post) | **POST** /campaign/{campaignId}/resume | Resumes a campaign.
*CampaignApi* | [**campaign_monitor_get**](rapidata/api_client/docs/CampaignApi.md#campaign_monitor_get) | **GET** /campaign/monitor | The monitor endpoint is used to monitor the health of the service
*CampaignApi* | [**campaigns_get**](rapidata/api_client/docs/CampaignApi.md#campaigns_get) | **GET** /campaigns | Queries orders based on a filter, page, and sort criteria.
*ClientApi* | [**client_client_id_delete**](rapidata/api_client/docs/ClientApi.md#client_client_id_delete) | **DELETE** /client/{clientId} | Deletes a customers&#39; client.
*ClientApi* | [**client_client_id_get**](rapidata/api_client/docs/ClientApi.md#client_client_id_get) | **GET** /client/{clientId} | Gets a specific client by its ID.
*ClientApi* | [**client_post**](rapidata/api_client/docs/ClientApi.md#client_post) | **POST** /client | Creates a new client for the current customer.
*ClientApi* | [**client_register_post**](rapidata/api_client/docs/ClientApi.md#client_register_post) | **POST** /client/register | Registers a new client dynamically.
*ClientApi* | [**clients_get**](rapidata/api_client/docs/ClientApi.md#clients_get) | **GET** /clients | Queries the clients for the current customer.
*CocoApi* | [**coco_coco_set_id_submit_post**](rapidata/api_client/docs/CocoApi.md#coco_coco_set_id_submit_post) | **POST** /coco/{cocoSetId}/submit | Creates a new validation set based on a previously uploaded CoCo set.
*CocoApi* | [**coco_post**](rapidata/api_client/docs/CocoApi.md#coco_post) | **POST** /coco | Uploads a CoCo set to the system.
*CompareWorkflowApi* | [**workflow_compare_workflow_id_results_get**](rapidata/api_client/docs/CompareWorkflowApi.md#workflow_compare_workflow_id_results_get) | **GET** /workflow/compare/{workflowId}/results | Get the result overview for a compare workflow.
*CustomerRapidApi* | [**rapid_correlation_id_validation_potential_get**](rapidata/api_client/docs/CustomerRapidApi.md#rapid_correlation_id_validation_potential_get) | **GET** /rapid/{correlationId}/validation-potential | Queries rapids that are potentially eligible for validation set creation.
*CustomerRapidApi* | [**rapid_demographic_post**](rapidata/api_client/docs/CustomerRapidApi.md#rapid_demographic_post) | **POST** /rapid/demographic | Creates a new Demographic Rapid.
*CustomerRapidApi* | [**rapid_rapid_id_delete**](rapidata/api_client/docs/CustomerRapidApi.md#rapid_rapid_id_delete) | **DELETE** /rapid/{rapidId} | Deletes a rapid.
*CustomerRapidApi* | [**rapid_rapid_id_responses_get**](rapidata/api_client/docs/CustomerRapidApi.md#rapid_rapid_id_responses_get) | **GET** /rapid/{rapidId}/responses | Gets all responses for a given rapid.
*CustomerRapidApi* | [**rapid_rapid_id_unflag_post**](rapidata/api_client/docs/CustomerRapidApi.md#rapid_rapid_id_unflag_post) | **POST** /rapid/{rapidId}/unflag | Unflags a flagged rapid. This will add the rapid back to the active labeling pool and prevent it from being flagged again.
*CustomerRapidApi* | [**rapid_validation_rapid_id_patch**](rapidata/api_client/docs/CustomerRapidApi.md#rapid_validation_rapid_id_patch) | **PATCH** /rapid/validation/{rapidId} | Updates the validation information of a Rapid.
*CustomerRapidApi* | [**rapids_flagged_get**](rapidata/api_client/docs/CustomerRapidApi.md#rapids_flagged_get) | **GET** /rapids/flagged | Allows querying all rapids that have been flagged.
*DatapointApi* | [**datapoint_datapoint_id_delete**](rapidata/api_client/docs/DatapointApi.md#datapoint_datapoint_id_delete) | **DELETE** /datapoint/{datapointId} | Deletes a datapoint by its id.
*DatapointApi* | [**datapoint_datapoint_id_get**](rapidata/api_client/docs/DatapointApi.md#datapoint_datapoint_id_get) | **GET** /datapoint/{datapointId} | Gets a datapoint by its id.
*DatasetApi* | [**dataset_dataset_id_datapoints_csv_post**](rapidata/api_client/docs/DatasetApi.md#dataset_dataset_id_datapoints_csv_post) | **POST** /dataset/{datasetId}/datapoints/csv | Creates multiple datapoints from a csv.
*DatasetApi* | [**dataset_dataset_id_datapoints_failed_get**](rapidata/api_client/docs/DatasetApi.md#dataset_dataset_id_datapoints_failed_get) | **GET** /dataset/{datasetId}/datapoints/failed | Gets a list of all datapoints that failed to upload.
*DatasetApi* | [**dataset_dataset_id_datapoints_files_post**](rapidata/api_client/docs/DatasetApi.md#dataset_dataset_id_datapoints_files_post) | **POST** /dataset/{datasetId}/datapoints/files | Creates a single datapoint by uploading files.
*DatasetApi* | [**dataset_dataset_id_datapoints_get**](rapidata/api_client/docs/DatasetApi.md#dataset_dataset_id_datapoints_get) | **GET** /dataset/{datasetId}/datapoints | Gets all datapoints of a dataset.
*DatasetApi* | [**dataset_dataset_id_datapoints_post**](rapidata/api_client/docs/DatasetApi.md#dataset_dataset_id_datapoints_post) | **POST** /dataset/{datasetId}/datapoints | Creates a new datapoint from multiple possible sources.
*DatasetApi* | [**dataset_dataset_id_datapoints_s3_post**](rapidata/api_client/docs/DatasetApi.md#dataset_dataset_id_datapoints_s3_post) | **POST** /dataset/{datasetId}/datapoints/s3 | Uploads files from an S3 bucket to a dataset.
*DatasetApi* | [**dataset_dataset_id_datapoints_texts_post**](rapidata/api_client/docs/DatasetApi.md#dataset_dataset_id_datapoints_texts_post) | **POST** /dataset/{datasetId}/datapoints/texts | Creates a single datapoint from text sources.
*DatasetApi* | [**dataset_dataset_id_datapoints_urls_post**](rapidata/api_client/docs/DatasetApi.md#dataset_dataset_id_datapoints_urls_post) | **POST** /dataset/{datasetId}/datapoints/urls | Creates a single datapoint where the assets are fetched from the specified urls.
*DatasetApi* | [**dataset_dataset_id_get**](rapidata/api_client/docs/DatasetApi.md#dataset_dataset_id_get) | **GET** /dataset/{datasetId} | Gets a dataset by its id.
*DatasetApi* | [**dataset_dataset_id_name_patch**](rapidata/api_client/docs/DatasetApi.md#dataset_dataset_id_name_patch) | **PATCH** /dataset/{datasetId}/name | Updates the name of a dataset.
*DatasetApi* | [**dataset_dataset_id_progress_get**](rapidata/api_client/docs/DatasetApi.md#dataset_dataset_id_progress_get) | **GET** /dataset/{datasetId}/progress | Gets the upload progress of a dataset.
*EvaluationWorkflowApi* | [**workflow_evaluation_workflow_id_results_get**](rapidata/api_client/docs/EvaluationWorkflowApi.md#workflow_evaluation_workflow_id_results_get) | **GET** /workflow/evaluation/{workflowId}/results | Get the results for an evaluation workflow.
*FeedbackApi* | [**feedback_post**](rapidata/api_client/docs/FeedbackApi.md#feedback_post) | **POST** /feedback | Submits feedback about our services.
*IdentityApi* | [**identity_bridge_token_get**](rapidata/api_client/docs/IdentityApi.md#identity_bridge_token_get) | **GET** /identity/bridge-token | Tries to read the bridge token keys for a given read key. The read key is used to retrieve the authentication result written by the write key.
*IdentityApi* | [**identity_bridge_token_post**](rapidata/api_client/docs/IdentityApi.md#identity_bridge_token_post) | **POST** /identity/bridge-token | Creates a pair of read and write keys for a client. The write key is used to store the authentication result. The read key is used to retrieve the authentication result.
*IdentityApi* | [**identity_google_one_tap_post**](rapidata/api_client/docs/IdentityApi.md#identity_google_one_tap_post) | **POST** /identity/google-one-tap | Signs in a user using a token received from Google One Tap.
*IdentityApi* | [**identity_referrer_post**](rapidata/api_client/docs/IdentityApi.md#identity_referrer_post) | **POST** /identity/referrer | Sets the referrer for the current customer.
*IdentityApi* | [**identity_temporary_post**](rapidata/api_client/docs/IdentityApi.md#identity_temporary_post) | **POST** /identity/temporary | Registers and logs in a temporary customer.
*LeaderboardApi* | [**benchmark_standing_leaderboard_id_participant_id_get**](rapidata/api_client/docs/LeaderboardApi.md#benchmark_standing_leaderboard_id_participant_id_get) | **GET** /benchmark/standing/{leaderboardId}/{participantId} | Gets a standing by leaderboardId and participantId.
*LeaderboardApi* | [**leaderboard_leaderboard_id_boost_post**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_boost_post) | **POST** /leaderboard/{leaderboardId}/boost | Boosts a subset of participants within a leaderboard.
*LeaderboardApi* | [**leaderboard_leaderboard_id_delete**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_delete) | **DELETE** /leaderboard/{leaderboardId} | Deletes a leaderboard by its ID.
*LeaderboardApi* | [**leaderboard_leaderboard_id_get**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_get) | **GET** /leaderboard/{leaderboardId} | Gets a leaderboard by its ID.
*LeaderboardApi* | [**leaderboard_leaderboard_id_name_put**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_name_put) | **PUT** /leaderboard/{leaderboardId}/name | Updates the name of a leaderboard.
*LeaderboardApi* | [**leaderboard_leaderboard_id_participant_participant_id_get**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_participant_participant_id_get) | **GET** /leaderboard/{leaderboardId}/participant/{participantId} | Gets a participant by its ID.
*LeaderboardApi* | [**leaderboard_leaderboard_id_participants_get**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_participants_get) | **GET** /leaderboard/{leaderboardId}/participants | queries all the participants connected to leaderboard by its ID.
*LeaderboardApi* | [**leaderboard_leaderboard_id_participants_participant_id_submit_post**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_participants_participant_id_submit_post) | **POST** /leaderboard/{leaderboardId}/participants/{participantId}/submit | Submits a participant to a leaderboard.
*LeaderboardApi* | [**leaderboard_leaderboard_id_participants_post**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_participants_post) | **POST** /leaderboard/{leaderboardId}/participants | Creates a participant in a leaderboard.
*LeaderboardApi* | [**leaderboard_leaderboard_id_prompts_get**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_prompts_get) | **GET** /leaderboard/{leaderboardId}/prompts | returns the paged prompts of a leaderboard by its ID.
*LeaderboardApi* | [**leaderboard_leaderboard_id_prompts_post**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_prompts_post) | **POST** /leaderboard/{leaderboardId}/prompts | adds a new prompt to a leaderboard.
*LeaderboardApi* | [**leaderboard_leaderboard_id_refresh_post**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_refresh_post) | **POST** /leaderboard/{leaderboardId}/refresh | This will force an update to all standings of a leaderboard. this could happen if the recorded matches and scores are out of sync
*LeaderboardApi* | [**leaderboard_leaderboard_id_runs_get**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_runs_get) | **GET** /leaderboard/{leaderboardId}/runs | Gets the runs related to a leaderboard
*LeaderboardApi* | [**leaderboard_leaderboard_id_standings_get**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_leaderboard_id_standings_get) | **GET** /leaderboard/{leaderboardId}/standings | queries all the participants connected to leaderboard by its ID.
*LeaderboardApi* | [**leaderboard_post**](rapidata/api_client/docs/LeaderboardApi.md#leaderboard_post) | **POST** /leaderboard | Creates a new leaderboard with the specified name and criteria.
*LeaderboardApi* | [**leaderboards_get**](rapidata/api_client/docs/LeaderboardApi.md#leaderboards_get) | **GET** /leaderboards | Queries all leaderboards of the user.
*NewsletterApi* | [**newsletter_subscribe_post**](rapidata/api_client/docs/NewsletterApi.md#newsletter_subscribe_post) | **POST** /newsletter/subscribe | Signs a user up to the newsletter.
*NewsletterApi* | [**newsletter_unsubscribe_post**](rapidata/api_client/docs/NewsletterApi.md#newsletter_unsubscribe_post) | **POST** /newsletter/unsubscribe | Unsubscribes a user from the newsletter.
*OrderApi* | [**order_complex_post**](rapidata/api_client/docs/OrderApi.md#order_complex_post) | **POST** /order/complex | Creates a new order with a custom pipeline.
*OrderApi* | [**order_order_id_approve_post**](rapidata/api_client/docs/OrderApi.md#order_order_id_approve_post) | **POST** /order/{orderId}/approve | Approves an order that has been submitted for manual approval.
*OrderApi* | [**order_order_id_clone_post**](rapidata/api_client/docs/OrderApi.md#order_order_id_clone_post) | **POST** /order/{orderId}/clone | Clones an existing order.
*OrderApi* | [**order_order_id_delete**](rapidata/api_client/docs/OrderApi.md#order_order_id_delete) | **DELETE** /order/{orderId} | Deletes an order.
*OrderApi* | [**order_order_id_demo_patch**](rapidata/api_client/docs/OrderApi.md#order_order_id_demo_patch) | **PATCH** /order/{orderId}/demo | Updates whether an order is a demo or not.
*OrderApi* | [**order_order_id_download_results_get**](rapidata/api_client/docs/OrderApi.md#order_order_id_download_results_get) | **GET** /order/{orderId}/download-results | Aggregates the results of an order and returns it as a file attachment.
*OrderApi* | [**order_order_id_get**](rapidata/api_client/docs/OrderApi.md#order_order_id_get) | **GET** /order/{orderId} | Retrieves an order by its id.
*OrderApi* | [**order_order_id_name_patch**](rapidata/api_client/docs/OrderApi.md#order_order_id_name_patch) | **PATCH** /order/{orderId}/name | Updates the name of an order.
*OrderApi* | [**order_order_id_pause_post**](rapidata/api_client/docs/OrderApi.md#order_order_id_pause_post) | **POST** /order/{orderId}/pause | Pauses an order that is processing. Meaning all campaigns in the order will be paused.
*OrderApi* | [**order_order_id_preview_post**](rapidata/api_client/docs/OrderApi.md#order_order_id_preview_post) | **POST** /order/{orderId}/preview | Puts the order into preview mode, where one can inspect what our labelers receive.
*OrderApi* | [**order_order_id_results_get**](rapidata/api_client/docs/OrderApi.md#order_order_id_results_get) | **GET** /order/{orderId}/results | Aggregates the results of an order and returns the result as a json body.
*OrderApi* | [**order_order_id_resume_post**](rapidata/api_client/docs/OrderApi.md#order_order_id_resume_post) | **POST** /order/{orderId}/resume | Resumes a paused order. Meaning all campaigns in the order will be resumed.
*OrderApi* | [**order_order_id_retry_post**](rapidata/api_client/docs/OrderApi.md#order_order_id_retry_post) | **POST** /order/{orderId}/retry | Retries a failed order.
*OrderApi* | [**order_order_id_share_patch**](rapidata/api_client/docs/OrderApi.md#order_order_id_share_patch) | **PATCH** /order/{orderId}/share | Updates whether an order is public or not.
*OrderApi* | [**order_order_id_submit_post**](rapidata/api_client/docs/OrderApi.md#order_order_id_submit_post) | **POST** /order/{orderId}/submit | Submits an order for approval.
*OrderApi* | [**order_order_id_unlock_post**](rapidata/api_client/docs/OrderApi.md#order_order_id_unlock_post) | **POST** /order/{orderId}/unlock | Unlocks a newly cloned order.
*OrderApi* | [**order_post**](rapidata/api_client/docs/OrderApi.md#order_post) | **POST** /order | Used to create a new order.
*OrderApi* | [**order_unsupported_post**](rapidata/api_client/docs/OrderApi.md#order_unsupported_post) | **POST** /order/unsupported | Notifies the admins that a user wants to create an order with an unsupported label type or data type.
*OrderApi* | [**orders_get**](rapidata/api_client/docs/OrderApi.md#orders_get) | **GET** /orders | Queries orders based on a filter, page, and sort criteria.
*OrderApi* | [**orders_public_get**](rapidata/api_client/docs/OrderApi.md#orders_public_get) | **GET** /orders/public | Retrieves orders that are public and can be cloned by any user.
*PipelineApi* | [**pipeline_id_workflow_config_artifact_id_put**](rapidata/api_client/docs/PipelineApi.md#pipeline_id_workflow_config_artifact_id_put) | **PUT** /pipeline/{id}/workflow-config/{artifactId} | Updates the workflow configuration for a pipeline.
*PipelineApi* | [**pipeline_id_workflow_config_put**](rapidata/api_client/docs/PipelineApi.md#pipeline_id_workflow_config_put) | **PUT** /pipeline/{id}/workflow-config | Updates the workflow configuration for a pipeline.
*PipelineApi* | [**pipeline_pipeline_id_campaign_artifact_id_put**](rapidata/api_client/docs/PipelineApi.md#pipeline_pipeline_id_campaign_artifact_id_put) | **PUT** /pipeline/{pipelineId}/campaign/{artifactId} | Updates a specific campaign for a pipeline.
*PipelineApi* | [**pipeline_pipeline_id_campaign_post**](rapidata/api_client/docs/PipelineApi.md#pipeline_pipeline_id_campaign_post) | **POST** /pipeline/{pipelineId}/campaign | Adds a campaign to a pipeline.
*PipelineApi* | [**pipeline_pipeline_id_campaign_put**](rapidata/api_client/docs/PipelineApi.md#pipeline_pipeline_id_campaign_put) | **PUT** /pipeline/{pipelineId}/campaign | Updates a specific campaign for a pipeline.
*PipelineApi* | [**pipeline_pipeline_id_get**](rapidata/api_client/docs/PipelineApi.md#pipeline_pipeline_id_get) | **GET** /pipeline/{pipelineId} | Gets a pipeline by its id.
*PipelineApi* | [**pipeline_pipeline_id_preliminary_download_post**](rapidata/api_client/docs/PipelineApi.md#pipeline_pipeline_id_preliminary_download_post) | **POST** /pipeline/{pipelineId}/preliminary-download | Initiates a preliminary download of the pipeline.
*PipelineApi* | [**pipeline_preliminary_download_preliminary_download_id_get**](rapidata/api_client/docs/PipelineApi.md#pipeline_preliminary_download_preliminary_download_id_get) | **GET** /pipeline/preliminary-download/{preliminaryDownloadId} | Gets the preliminary download.
*RapidataIdentityAPIApi* | [**root_get**](rapidata/api_client/docs/RapidataIdentityAPIApi.md#root_get) | **GET** / | 
*SimpleWorkflowApi* | [**workflow_simple_workflow_id_results_get**](rapidata/api_client/docs/SimpleWorkflowApi.md#workflow_simple_workflow_id_results_get) | **GET** /workflow/simple/{workflowId}/results | Get the result overview for a simple workflow.
*UserInfoApi* | [**connect_userinfo_get**](rapidata/api_client/docs/UserInfoApi.md#connect_userinfo_get) | **GET** /connect/userinfo | Retrieves information about the authenticated user.
*UserRapidApi* | [**rapid_rapid_bag_is_valid_get**](rapidata/api_client/docs/UserRapidApi.md#rapid_rapid_bag_is_valid_get) | **GET** /rapid/rapid-bag/is-valid | Validates that the rapids associated with the current user are active.
*UserRapidApi* | [**rapid_rapid_id_report_post**](rapidata/api_client/docs/UserRapidApi.md#rapid_rapid_id_report_post) | **POST** /rapid/{rapidId}/report | Used to report an issue with a rapid.
*UserRapidApi* | [**rapid_report_report_id_get**](rapidata/api_client/docs/UserRapidApi.md#rapid_report_report_id_get) | **GET** /rapid/report/{reportId} | Inspects a report&#39;s dump. Can be used to restore zustand state or anything alike.
*UserRapidApi* | [**rapid_response_post**](rapidata/api_client/docs/UserRapidApi.md#rapid_response_post) | **POST** /rapid/response | Submits a response for a Rapid.
*UserRapidApi* | [**rapid_skip_post**](rapidata/api_client/docs/UserRapidApi.md#rapid_skip_post) | **POST** /rapid/skip | Skips a Rapid for the user.
*ValidationSetApi* | [**validation_set_post**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_post) | **POST** /validation-set | Creates a new empty validation set.
*ValidationSetApi* | [**validation_set_validation_set_id_delete**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_validation_set_id_delete) | **DELETE** /validation-set/{validationSetId} | Gets a validation set by the id.
*ValidationSetApi* | [**validation_set_validation_set_id_dimensions_put**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_validation_set_id_dimensions_put) | **PUT** /validation-set/{validationSetId}/dimensions | Updates the dimensions of all rapids within a validation set.
*ValidationSetApi* | [**validation_set_validation_set_id_export_get**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_validation_set_id_export_get) | **GET** /validation-set/{validationSetId}/export | Exports all rapids of a validation-set to a file.
*ValidationSetApi* | [**validation_set_validation_set_id_get**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_validation_set_id_get) | **GET** /validation-set/{validationSetId} | Gets a validation set by the id.
*ValidationSetApi* | [**validation_set_validation_set_id_rapid_files_post**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_validation_set_id_rapid_files_post) | **POST** /validation-set/{validationSetId}/rapid/files | Adds a new validation rapid to the specified validation set using files to create the assets.
*ValidationSetApi* | [**validation_set_validation_set_id_rapid_post**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_validation_set_id_rapid_post) | **POST** /validation-set/{validationSetId}/rapid | Adds a new validation rapid to the specified validation set using files to create the assets.
*ValidationSetApi* | [**validation_set_validation_set_id_rapid_texts_post**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_validation_set_id_rapid_texts_post) | **POST** /validation-set/{validationSetId}/rapid/texts | Adds a new validation rapid to the specified validation set using text sources to create the assets.
*ValidationSetApi* | [**validation_set_validation_set_id_rapids_get**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_validation_set_id_rapids_get) | **GET** /validation-set/{validationSetId}/rapids | Queries the validation rapids for a specific validation set.
*ValidationSetApi* | [**validation_set_zip_compare_post**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_zip_compare_post) | **POST** /validation-set/zip/compare | Imports a compare validation set from a zip file.
*ValidationSetApi* | [**validation_set_zip_post**](rapidata/api_client/docs/ValidationSetApi.md#validation_set_zip_post) | **POST** /validation-set/zip | Imports a validation set from a zip file.
*ValidationSetApi* | [**validation_sets_available_get**](rapidata/api_client/docs/ValidationSetApi.md#validation_sets_available_get) | **GET** /validation-sets/available | Gets the available validation sets for the current user.
*ValidationSetApi* | [**validation_sets_get**](rapidata/api_client/docs/ValidationSetApi.md#validation_sets_get) | **GET** /validation-sets | Queries validation sets based on the provided filter, paging and sorting criteria.
*WorkflowApi* | [**workflow_delete_delete**](rapidata/api_client/docs/WorkflowApi.md#workflow_delete_delete) | **DELETE** /workflow/delete | Deletes a workflow.
*WorkflowApi* | [**workflow_workflow_id_compare_ab_summary_get**](rapidata/api_client/docs/WorkflowApi.md#workflow_workflow_id_compare_ab_summary_get) | **GET** /workflow/{workflowId}/compare-ab-summary | Calculates a summary of the results for a simple compare workflow. The summary includes the number of times an asset at each index was the winner.
*WorkflowApi* | [**workflow_workflow_id_get**](rapidata/api_client/docs/WorkflowApi.md#workflow_workflow_id_get) | **GET** /workflow/{workflowId} | Get a workflow by its ID.
*WorkflowApi* | [**workflow_workflow_id_progress_get**](rapidata/api_client/docs/WorkflowApi.md#workflow_workflow_id_progress_get) | **GET** /workflow/{workflowId}/progress | Get the progress of a workflow.
*WorkflowApi* | [**workflow_workflow_id_responses_get**](rapidata/api_client/docs/WorkflowApi.md#workflow_workflow_id_responses_get) | **GET** /workflow/{workflowId}/responses | Gets the limit most recent or oldest responses for a workflow. The responses are not guaranteed to be of any specific rapid. Instead, this endpoint returns all responses to any rapid in the workflow.
*WorkflowApi* | [**workflows_get**](rapidata/api_client/docs/WorkflowApi.md#workflows_get) | **GET** /workflows | Queries workflows based on the provided filter, page, and sort criteria.


## Documentation For Models

 - [AbTestSelection](rapidata/api_client/docs/AbTestSelection.md)
 - [AbTestSelectionAInner](rapidata/api_client/docs/AbTestSelectionAInner.md)
 - [AddCampaignArtifactResult](rapidata/api_client/docs/AddCampaignArtifactResult.md)
 - [AddCampaignModel](rapidata/api_client/docs/AddCampaignModel.md)
 - [AddUserResponseResult](rapidata/api_client/docs/AddUserResponseResult.md)
 - [AddValidationRapidModel](rapidata/api_client/docs/AddValidationRapidModel.md)
 - [AddValidationRapidModelPayload](rapidata/api_client/docs/AddValidationRapidModelPayload.md)
 - [AddValidationRapidModelTruth](rapidata/api_client/docs/AddValidationRapidModelTruth.md)
 - [AddValidationRapidResult](rapidata/api_client/docs/AddValidationRapidResult.md)
 - [AddValidationTextRapidModel](rapidata/api_client/docs/AddValidationTextRapidModel.md)
 - [AgeGroup](rapidata/api_client/docs/AgeGroup.md)
 - [AgeUserFilterModel](rapidata/api_client/docs/AgeUserFilterModel.md)
 - [AggregatorType](rapidata/api_client/docs/AggregatorType.md)
 - [AndUserFilterModel](rapidata/api_client/docs/AndUserFilterModel.md)
 - [AndUserFilterModelFiltersInner](rapidata/api_client/docs/AndUserFilterModelFiltersInner.md)
 - [AreRapidsActiveResult](rapidata/api_client/docs/AreRapidsActiveResult.md)
 - [AssetMetadata](rapidata/api_client/docs/AssetMetadata.md)
 - [AssetMetadataAsset](rapidata/api_client/docs/AssetMetadataAsset.md)
 - [AssetMetadataModel](rapidata/api_client/docs/AssetMetadataModel.md)
 - [AttachCategoryRapidBlueprint](rapidata/api_client/docs/AttachCategoryRapidBlueprint.md)
 - [AttachCategoryResult](rapidata/api_client/docs/AttachCategoryResult.md)
 - [AttachCategoryTruth](rapidata/api_client/docs/AttachCategoryTruth.md)
 - [BenchmarkQueryResult](rapidata/api_client/docs/BenchmarkQueryResult.md)
 - [BenchmarkQueryResultPagedResult](rapidata/api_client/docs/BenchmarkQueryResultPagedResult.md)
 - [BoostLeaderboardModel](rapidata/api_client/docs/BoostLeaderboardModel.md)
 - [BoostQueryResult](rapidata/api_client/docs/BoostQueryResult.md)
 - [BoostStatus](rapidata/api_client/docs/BoostStatus.md)
 - [BoundingBoxPayload](rapidata/api_client/docs/BoundingBoxPayload.md)
 - [BoundingBoxRapidBlueprint](rapidata/api_client/docs/BoundingBoxRapidBlueprint.md)
 - [BoundingBoxResult](rapidata/api_client/docs/BoundingBoxResult.md)
 - [BoundingBoxTruth](rapidata/api_client/docs/BoundingBoxTruth.md)
 - [BoxShape](rapidata/api_client/docs/BoxShape.md)
 - [CampaignArtifactModel](rapidata/api_client/docs/CampaignArtifactModel.md)
 - [CampaignQueryResult](rapidata/api_client/docs/CampaignQueryResult.md)
 - [CampaignQueryResultPagedResult](rapidata/api_client/docs/CampaignQueryResultPagedResult.md)
 - [CampaignStatus](rapidata/api_client/docs/CampaignStatus.md)
 - [CampaignUserFilterModel](rapidata/api_client/docs/CampaignUserFilterModel.md)
 - [CappedSelection](rapidata/api_client/docs/CappedSelection.md)
 - [ClassificationMetadata](rapidata/api_client/docs/ClassificationMetadata.md)
 - [ClassificationMetadataFilterConfig](rapidata/api_client/docs/ClassificationMetadataFilterConfig.md)
 - [ClassificationMetadataModel](rapidata/api_client/docs/ClassificationMetadataModel.md)
 - [ClassifyPayload](rapidata/api_client/docs/ClassifyPayload.md)
 - [ClientModel](rapidata/api_client/docs/ClientModel.md)
 - [ClientsQueryResult](rapidata/api_client/docs/ClientsQueryResult.md)
 - [ClientsQueryResultPagedResult](rapidata/api_client/docs/ClientsQueryResultPagedResult.md)
 - [CloneDatasetModel](rapidata/api_client/docs/CloneDatasetModel.md)
 - [CloneOrderModel](rapidata/api_client/docs/CloneOrderModel.md)
 - [CloneOrderResult](rapidata/api_client/docs/CloneOrderResult.md)
 - [ComparePayload](rapidata/api_client/docs/ComparePayload.md)
 - [CompareRapidBlueprint](rapidata/api_client/docs/CompareRapidBlueprint.md)
 - [CompareResult](rapidata/api_client/docs/CompareResult.md)
 - [CompareTruth](rapidata/api_client/docs/CompareTruth.md)
 - [CompareWorkflowConfig](rapidata/api_client/docs/CompareWorkflowConfig.md)
 - [CompareWorkflowConfigMetadataValue](rapidata/api_client/docs/CompareWorkflowConfigMetadataValue.md)
 - [CompareWorkflowConfigModel](rapidata/api_client/docs/CompareWorkflowConfigModel.md)
 - [CompareWorkflowConfigModelPairMakerConfig](rapidata/api_client/docs/CompareWorkflowConfigModelPairMakerConfig.md)
 - [CompareWorkflowConfigPairMakerConfig](rapidata/api_client/docs/CompareWorkflowConfigPairMakerConfig.md)
 - [CompareWorkflowModel](rapidata/api_client/docs/CompareWorkflowModel.md)
 - [CompareWorkflowModel1](rapidata/api_client/docs/CompareWorkflowModel1.md)
 - [CompareWorkflowModel1PairMakerInformation](rapidata/api_client/docs/CompareWorkflowModel1PairMakerInformation.md)
 - [CompareWorkflowModel1Referee](rapidata/api_client/docs/CompareWorkflowModel1Referee.md)
 - [CompareWorkflowModelPairMakerConfig](rapidata/api_client/docs/CompareWorkflowModelPairMakerConfig.md)
 - [ComparisonOperator](rapidata/api_client/docs/ComparisonOperator.md)
 - [ConditionalValidationSelection](rapidata/api_client/docs/ConditionalValidationSelection.md)
 - [Coordinate](rapidata/api_client/docs/Coordinate.md)
 - [CountClassificationMetadataFilterConfig](rapidata/api_client/docs/CountClassificationMetadataFilterConfig.md)
 - [CountMetadata](rapidata/api_client/docs/CountMetadata.md)
 - [CountMetadataModel](rapidata/api_client/docs/CountMetadataModel.md)
 - [CountryUserFilterModel](rapidata/api_client/docs/CountryUserFilterModel.md)
 - [CreateBenchmarkModel](rapidata/api_client/docs/CreateBenchmarkModel.md)
 - [CreateBenchmarkParticipantModel](rapidata/api_client/docs/CreateBenchmarkParticipantModel.md)
 - [CreateBenchmarkParticipantResult](rapidata/api_client/docs/CreateBenchmarkParticipantResult.md)
 - [CreateBenchmarkResult](rapidata/api_client/docs/CreateBenchmarkResult.md)
 - [CreateBridgeTokenResult](rapidata/api_client/docs/CreateBridgeTokenResult.md)
 - [CreateClientModel](rapidata/api_client/docs/CreateClientModel.md)
 - [CreateComplexOrderModel](rapidata/api_client/docs/CreateComplexOrderModel.md)
 - [CreateComplexOrderModelPipeline](rapidata/api_client/docs/CreateComplexOrderModelPipeline.md)
 - [CreateComplexOrderResult](rapidata/api_client/docs/CreateComplexOrderResult.md)
 - [CreateCustomerClientResult](rapidata/api_client/docs/CreateCustomerClientResult.md)
 - [CreateDatapointFromFilesModel](rapidata/api_client/docs/CreateDatapointFromFilesModel.md)
 - [CreateDatapointFromTextSourcesModel](rapidata/api_client/docs/CreateDatapointFromTextSourcesModel.md)
 - [CreateDatapointFromUrlsModel](rapidata/api_client/docs/CreateDatapointFromUrlsModel.md)
 - [CreateDatapointResult](rapidata/api_client/docs/CreateDatapointResult.md)
 - [CreateDatapointsFromS3BucketModel](rapidata/api_client/docs/CreateDatapointsFromS3BucketModel.md)
 - [CreateDatasetArtifactModel](rapidata/api_client/docs/CreateDatasetArtifactModel.md)
 - [CreateDatasetArtifactModelDataset](rapidata/api_client/docs/CreateDatasetArtifactModelDataset.md)
 - [CreateDemographicRapidModel](rapidata/api_client/docs/CreateDemographicRapidModel.md)
 - [CreateEmptyValidationSetResult](rapidata/api_client/docs/CreateEmptyValidationSetResult.md)
 - [CreateLeaderboardModel](rapidata/api_client/docs/CreateLeaderboardModel.md)
 - [CreateLeaderboardResult](rapidata/api_client/docs/CreateLeaderboardResult.md)
 - [CreateOrderModel](rapidata/api_client/docs/CreateOrderModel.md)
 - [CreateOrderModelReferee](rapidata/api_client/docs/CreateOrderModelReferee.md)
 - [CreateOrderModelWorkflow](rapidata/api_client/docs/CreateOrderModelWorkflow.md)
 - [CreateOrderResult](rapidata/api_client/docs/CreateOrderResult.md)
 - [CreateRapidResult](rapidata/api_client/docs/CreateRapidResult.md)
 - [CreateSimplePipelineModel](rapidata/api_client/docs/CreateSimplePipelineModel.md)
 - [CreateSimplePipelineModelArtifactsInner](rapidata/api_client/docs/CreateSimplePipelineModelArtifactsInner.md)
 - [CreateSimplePipelineModelPipelineStepsInner](rapidata/api_client/docs/CreateSimplePipelineModelPipelineStepsInner.md)
 - [CreateUnsupportedOrderModel](rapidata/api_client/docs/CreateUnsupportedOrderModel.md)
 - [CreateValidationSetModel](rapidata/api_client/docs/CreateValidationSetModel.md)
 - [CustomUserFilterModel](rapidata/api_client/docs/CustomUserFilterModel.md)
 - [Datapoint](rapidata/api_client/docs/Datapoint.md)
 - [DatapointAsset](rapidata/api_client/docs/DatapointAsset.md)
 - [DatapointModel](rapidata/api_client/docs/DatapointModel.md)
 - [DatapointModelPagedResult](rapidata/api_client/docs/DatapointModelPagedResult.md)
 - [DatapointState](rapidata/api_client/docs/DatapointState.md)
 - [DatasetArtifactModel](rapidata/api_client/docs/DatasetArtifactModel.md)
 - [DatasetDatasetIdDatapointsPostRequestMetadataInner](rapidata/api_client/docs/DatasetDatasetIdDatapointsPostRequestMetadataInner.md)
 - [DatasetEvaluationStepModel](rapidata/api_client/docs/DatasetEvaluationStepModel.md)
 - [Demographic](rapidata/api_client/docs/Demographic.md)
 - [DemographicMetadataModel](rapidata/api_client/docs/DemographicMetadataModel.md)
 - [DemographicSelection](rapidata/api_client/docs/DemographicSelection.md)
 - [DynamicClientRegistrationRequest](rapidata/api_client/docs/DynamicClientRegistrationRequest.md)
 - [EarlyStoppingRefereeModel](rapidata/api_client/docs/EarlyStoppingRefereeModel.md)
 - [EffortCappedSelection](rapidata/api_client/docs/EffortCappedSelection.md)
 - [EloConfig](rapidata/api_client/docs/EloConfig.md)
 - [EloConfigModel](rapidata/api_client/docs/EloConfigModel.md)
 - [EmptyValidationTruth](rapidata/api_client/docs/EmptyValidationTruth.md)
 - [EvaluationWorkflowConfig](rapidata/api_client/docs/EvaluationWorkflowConfig.md)
 - [EvaluationWorkflowModel](rapidata/api_client/docs/EvaluationWorkflowModel.md)
 - [EvaluationWorkflowModel1](rapidata/api_client/docs/EvaluationWorkflowModel1.md)
 - [FeatureFlag](rapidata/api_client/docs/FeatureFlag.md)
 - [FeatureFlagModel](rapidata/api_client/docs/FeatureFlagModel.md)
 - [FeedbackModel](rapidata/api_client/docs/FeedbackModel.md)
 - [FileArtifactModel](rapidata/api_client/docs/FileArtifactModel.md)
 - [FileAsset](rapidata/api_client/docs/FileAsset.md)
 - [FileAssetInput](rapidata/api_client/docs/FileAssetInput.md)
 - [FileAssetInput1](rapidata/api_client/docs/FileAssetInput1.md)
 - [FileAssetInput1File](rapidata/api_client/docs/FileAssetInput1File.md)
 - [FileAssetInput2](rapidata/api_client/docs/FileAssetInput2.md)
 - [FileAssetInput3](rapidata/api_client/docs/FileAssetInput3.md)
 - [FileAssetInputFile](rapidata/api_client/docs/FileAssetInputFile.md)
 - [FileAssetModel](rapidata/api_client/docs/FileAssetModel.md)
 - [FileAssetModelMetadataValue](rapidata/api_client/docs/FileAssetModelMetadataValue.md)
 - [FileType](rapidata/api_client/docs/FileType.md)
 - [FileTypeMetadata](rapidata/api_client/docs/FileTypeMetadata.md)
 - [FileTypeMetadataModel](rapidata/api_client/docs/FileTypeMetadataModel.md)
 - [Filter](rapidata/api_client/docs/Filter.md)
 - [FilterOperator](rapidata/api_client/docs/FilterOperator.md)
 - [FormFileWrapper](rapidata/api_client/docs/FormFileWrapper.md)
 - [FreeTextPayload](rapidata/api_client/docs/FreeTextPayload.md)
 - [FreeTextRapidBlueprint](rapidata/api_client/docs/FreeTextRapidBlueprint.md)
 - [FreeTextResult](rapidata/api_client/docs/FreeTextResult.md)
 - [Gender](rapidata/api_client/docs/Gender.md)
 - [GenderUserFilterModel](rapidata/api_client/docs/GenderUserFilterModel.md)
 - [GetAvailableValidationSetsResult](rapidata/api_client/docs/GetAvailableValidationSetsResult.md)
 - [GetBenchmarkByIdResult](rapidata/api_client/docs/GetBenchmarkByIdResult.md)
 - [GetCompareAbSummaryResult](rapidata/api_client/docs/GetCompareAbSummaryResult.md)
 - [GetCompareWorkflowResultsModel](rapidata/api_client/docs/GetCompareWorkflowResultsModel.md)
 - [GetCompareWorkflowResultsResult](rapidata/api_client/docs/GetCompareWorkflowResultsResult.md)
 - [GetCompareWorkflowResultsResultPagedResult](rapidata/api_client/docs/GetCompareWorkflowResultsResultPagedResult.md)
 - [GetDatapointByIdResult](rapidata/api_client/docs/GetDatapointByIdResult.md)
 - [GetDatasetByIdResult](rapidata/api_client/docs/GetDatasetByIdResult.md)
 - [GetDatasetProgressResult](rapidata/api_client/docs/GetDatasetProgressResult.md)
 - [GetFailedDatapointsResult](rapidata/api_client/docs/GetFailedDatapointsResult.md)
 - [GetLeaderboardByIdResult](rapidata/api_client/docs/GetLeaderboardByIdResult.md)
 - [GetOrderByIdResult](rapidata/api_client/docs/GetOrderByIdResult.md)
 - [GetParticipantByIdResult](rapidata/api_client/docs/GetParticipantByIdResult.md)
 - [GetPipelineByIdResult](rapidata/api_client/docs/GetPipelineByIdResult.md)
 - [GetPipelineByIdResultArtifactsValue](rapidata/api_client/docs/GetPipelineByIdResultArtifactsValue.md)
 - [GetPublicOrdersResult](rapidata/api_client/docs/GetPublicOrdersResult.md)
 - [GetRapidResponsesResult](rapidata/api_client/docs/GetRapidResponsesResult.md)
 - [GetResponsesResult](rapidata/api_client/docs/GetResponsesResult.md)
 - [GetSimpleWorkflowResultsModel](rapidata/api_client/docs/GetSimpleWorkflowResultsModel.md)
 - [GetStandingByIdResult](rapidata/api_client/docs/GetStandingByIdResult.md)
 - [GetValidationRapidsResult](rapidata/api_client/docs/GetValidationRapidsResult.md)
 - [GetValidationRapidsResultAsset](rapidata/api_client/docs/GetValidationRapidsResultAsset.md)
 - [GetValidationRapidsResultPagedResult](rapidata/api_client/docs/GetValidationRapidsResultPagedResult.md)
 - [GetValidationRapidsResultPayload](rapidata/api_client/docs/GetValidationRapidsResultPayload.md)
 - [GetValidationRapidsResultTruth](rapidata/api_client/docs/GetValidationRapidsResultTruth.md)
 - [GetValidationSetByIdResult](rapidata/api_client/docs/GetValidationSetByIdResult.md)
 - [GetWorkflowByIdResult](rapidata/api_client/docs/GetWorkflowByIdResult.md)
 - [GetWorkflowByIdResultWorkflow](rapidata/api_client/docs/GetWorkflowByIdResultWorkflow.md)
 - [GetWorkflowProgressResult](rapidata/api_client/docs/GetWorkflowProgressResult.md)
 - [GetWorkflowResultsResult](rapidata/api_client/docs/GetWorkflowResultsResult.md)
 - [GetWorkflowResultsResultPagedResult](rapidata/api_client/docs/GetWorkflowResultsResultPagedResult.md)
 - [GoogleOneTapLoginModel](rapidata/api_client/docs/GoogleOneTapLoginModel.md)
 - [IWorkflowModelPagedResult](rapidata/api_client/docs/IWorkflowModelPagedResult.md)
 - [ImageDimensionMetadata](rapidata/api_client/docs/ImageDimensionMetadata.md)
 - [ImageDimensionMetadataModel](rapidata/api_client/docs/ImageDimensionMetadataModel.md)
 - [ImportFromFileResult](rapidata/api_client/docs/ImportFromFileResult.md)
 - [ImportValidationSetFromFileResult](rapidata/api_client/docs/ImportValidationSetFromFileResult.md)
 - [InspectReportResult](rapidata/api_client/docs/InspectReportResult.md)
 - [JsonWebKey](rapidata/api_client/docs/JsonWebKey.md)
 - [JsonWebKeySet](rapidata/api_client/docs/JsonWebKeySet.md)
 - [LabelingSelection](rapidata/api_client/docs/LabelingSelection.md)
 - [LanguageUserFilterModel](rapidata/api_client/docs/LanguageUserFilterModel.md)
 - [LeaderboardQueryResult](rapidata/api_client/docs/LeaderboardQueryResult.md)
 - [LeaderboardQueryResultPagedResult](rapidata/api_client/docs/LeaderboardQueryResultPagedResult.md)
 - [Line](rapidata/api_client/docs/Line.md)
 - [LinePayload](rapidata/api_client/docs/LinePayload.md)
 - [LinePoint](rapidata/api_client/docs/LinePoint.md)
 - [LineRapidBlueprint](rapidata/api_client/docs/LineRapidBlueprint.md)
 - [LineResult](rapidata/api_client/docs/LineResult.md)
 - [LineTruth](rapidata/api_client/docs/LineTruth.md)
 - [LocalFileWrapper](rapidata/api_client/docs/LocalFileWrapper.md)
 - [LocateBoxTruth](rapidata/api_client/docs/LocateBoxTruth.md)
 - [LocateCoordinate](rapidata/api_client/docs/LocateCoordinate.md)
 - [LocatePayload](rapidata/api_client/docs/LocatePayload.md)
 - [LocateRapidBlueprint](rapidata/api_client/docs/LocateRapidBlueprint.md)
 - [LocateResult](rapidata/api_client/docs/LocateResult.md)
 - [LocationMetadata](rapidata/api_client/docs/LocationMetadata.md)
 - [LocationMetadataExistsFilterConfig](rapidata/api_client/docs/LocationMetadataExistsFilterConfig.md)
 - [LocationMetadataModel](rapidata/api_client/docs/LocationMetadataModel.md)
 - [LogicOperator](rapidata/api_client/docs/LogicOperator.md)
 - [MetadataVisibilities](rapidata/api_client/docs/MetadataVisibilities.md)
 - [MultiAsset](rapidata/api_client/docs/MultiAsset.md)
 - [MultiAssetInput](rapidata/api_client/docs/MultiAssetInput.md)
 - [MultiAssetInput1](rapidata/api_client/docs/MultiAssetInput1.md)
 - [MultiAssetInput1AssetsInner](rapidata/api_client/docs/MultiAssetInput1AssetsInner.md)
 - [MultiAssetInput2](rapidata/api_client/docs/MultiAssetInput2.md)
 - [MultiAssetInput3](rapidata/api_client/docs/MultiAssetInput3.md)
 - [MultiAssetInput3AssetsInner](rapidata/api_client/docs/MultiAssetInput3AssetsInner.md)
 - [MultiAssetInputAssetsInner](rapidata/api_client/docs/MultiAssetInputAssetsInner.md)
 - [MultiAssetModel](rapidata/api_client/docs/MultiAssetModel.md)
 - [MultiCompareTruth](rapidata/api_client/docs/MultiCompareTruth.md)
 - [NaiveRefereeConfig](rapidata/api_client/docs/NaiveRefereeConfig.md)
 - [NaiveRefereeInfo](rapidata/api_client/docs/NaiveRefereeInfo.md)
 - [NaiveRefereeModel](rapidata/api_client/docs/NaiveRefereeModel.md)
 - [NamedClassification](rapidata/api_client/docs/NamedClassification.md)
 - [NamedEntityPayload](rapidata/api_client/docs/NamedEntityPayload.md)
 - [NamedEntityRapidBlueprint](rapidata/api_client/docs/NamedEntityRapidBlueprint.md)
 - [NamedEntityResult](rapidata/api_client/docs/NamedEntityResult.md)
 - [NamedEntityTruth](rapidata/api_client/docs/NamedEntityTruth.md)
 - [NeverEndingRefereeConfig](rapidata/api_client/docs/NeverEndingRefereeConfig.md)
 - [NeverEndingRefereeInfo](rapidata/api_client/docs/NeverEndingRefereeInfo.md)
 - [NewUserFilterModel](rapidata/api_client/docs/NewUserFilterModel.md)
 - [NewsletterModel](rapidata/api_client/docs/NewsletterModel.md)
 - [NotAvailableYetResult](rapidata/api_client/docs/NotAvailableYetResult.md)
 - [NotUserFilterModel](rapidata/api_client/docs/NotUserFilterModel.md)
 - [NullAsset](rapidata/api_client/docs/NullAsset.md)
 - [NullAssetModel](rapidata/api_client/docs/NullAssetModel.md)
 - [OnlinePairMakerConfig](rapidata/api_client/docs/OnlinePairMakerConfig.md)
 - [OnlinePairMakerConfigModel](rapidata/api_client/docs/OnlinePairMakerConfigModel.md)
 - [OnlinePairMakerInformation](rapidata/api_client/docs/OnlinePairMakerInformation.md)
 - [OrUserFilterModel](rapidata/api_client/docs/OrUserFilterModel.md)
 - [OrderModel](rapidata/api_client/docs/OrderModel.md)
 - [OrderModelPagedResult](rapidata/api_client/docs/OrderModelPagedResult.md)
 - [OrderState](rapidata/api_client/docs/OrderState.md)
 - [OriginalFilenameMetadata](rapidata/api_client/docs/OriginalFilenameMetadata.md)
 - [OriginalFilenameMetadataModel](rapidata/api_client/docs/OriginalFilenameMetadataModel.md)
 - [PageInfo](rapidata/api_client/docs/PageInfo.md)
 - [ParticipantByBenchmark](rapidata/api_client/docs/ParticipantByBenchmark.md)
 - [ParticipantByBenchmarkPagedResult](rapidata/api_client/docs/ParticipantByBenchmarkPagedResult.md)
 - [ParticipantStatus](rapidata/api_client/docs/ParticipantStatus.md)
 - [PipelineIdWorkflowConfigPutRequest](rapidata/api_client/docs/PipelineIdWorkflowConfigPutRequest.md)
 - [PolygonPayload](rapidata/api_client/docs/PolygonPayload.md)
 - [PolygonRapidBlueprint](rapidata/api_client/docs/PolygonRapidBlueprint.md)
 - [PolygonResult](rapidata/api_client/docs/PolygonResult.md)
 - [PolygonTruth](rapidata/api_client/docs/PolygonTruth.md)
 - [PotentialValidationRapid](rapidata/api_client/docs/PotentialValidationRapid.md)
 - [PotentialValidationRapidPagedResult](rapidata/api_client/docs/PotentialValidationRapidPagedResult.md)
 - [PotentialValidationRapidTruth](rapidata/api_client/docs/PotentialValidationRapidTruth.md)
 - [PreliminaryDownloadModel](rapidata/api_client/docs/PreliminaryDownloadModel.md)
 - [PreliminaryDownloadResult](rapidata/api_client/docs/PreliminaryDownloadResult.md)
 - [PrivateTextMetadataInput](rapidata/api_client/docs/PrivateTextMetadataInput.md)
 - [ProbabilisticAttachCategoryRefereeConfig](rapidata/api_client/docs/ProbabilisticAttachCategoryRefereeConfig.md)
 - [ProbabilisticAttachCategoryRefereeInfo](rapidata/api_client/docs/ProbabilisticAttachCategoryRefereeInfo.md)
 - [PromptAssetMetadataInput](rapidata/api_client/docs/PromptAssetMetadataInput.md)
 - [PromptAssetMetadataInputAsset](rapidata/api_client/docs/PromptAssetMetadataInputAsset.md)
 - [PromptByBenchmarkResult](rapidata/api_client/docs/PromptByBenchmarkResult.md)
 - [PromptByBenchmarkResultPagedResult](rapidata/api_client/docs/PromptByBenchmarkResultPagedResult.md)
 - [PromptMetadata](rapidata/api_client/docs/PromptMetadata.md)
 - [PromptMetadataInput](rapidata/api_client/docs/PromptMetadataInput.md)
 - [PromptMetadataModel](rapidata/api_client/docs/PromptMetadataModel.md)
 - [ProxyFileWrapper](rapidata/api_client/docs/ProxyFileWrapper.md)
 - [PublicOrderModel](rapidata/api_client/docs/PublicOrderModel.md)
 - [PublicTextMetadataInput](rapidata/api_client/docs/PublicTextMetadataInput.md)
 - [QueryModel](rapidata/api_client/docs/QueryModel.md)
 - [QueryValidationModel](rapidata/api_client/docs/QueryValidationModel.md)
 - [RapidIssue](rapidata/api_client/docs/RapidIssue.md)
 - [RapidModel](rapidata/api_client/docs/RapidModel.md)
 - [RapidModelPagedResult](rapidata/api_client/docs/RapidModelPagedResult.md)
 - [RapidModelReferee](rapidata/api_client/docs/RapidModelReferee.md)
 - [RapidResponse](rapidata/api_client/docs/RapidResponse.md)
 - [RapidResponseResult](rapidata/api_client/docs/RapidResponseResult.md)
 - [RapidResultModel](rapidata/api_client/docs/RapidResultModel.md)
 - [RapidResultModelResult](rapidata/api_client/docs/RapidResultModelResult.md)
 - [RapidSkippedModel](rapidata/api_client/docs/RapidSkippedModel.md)
 - [RapidState](rapidata/api_client/docs/RapidState.md)
 - [ReadBridgeTokenKeysResult](rapidata/api_client/docs/ReadBridgeTokenKeysResult.md)
 - [RegisterTemporaryCustomerModel](rapidata/api_client/docs/RegisterTemporaryCustomerModel.md)
 - [RegisterTemporaryCustomerResult](rapidata/api_client/docs/RegisterTemporaryCustomerResult.md)
 - [ReportModel](rapidata/api_client/docs/ReportModel.md)
 - [ResponseCountUserFilterModel](rapidata/api_client/docs/ResponseCountUserFilterModel.md)
 - [RetrievalMode](rapidata/api_client/docs/RetrievalMode.md)
 - [RootFilter](rapidata/api_client/docs/RootFilter.md)
 - [RunStatus](rapidata/api_client/docs/RunStatus.md)
 - [RunsByLeaderboardResult](rapidata/api_client/docs/RunsByLeaderboardResult.md)
 - [RunsByLeaderboardResultPagedResult](rapidata/api_client/docs/RunsByLeaderboardResultPagedResult.md)
 - [ScrubPayload](rapidata/api_client/docs/ScrubPayload.md)
 - [ScrubRange](rapidata/api_client/docs/ScrubRange.md)
 - [ScrubRapidBlueprint](rapidata/api_client/docs/ScrubRapidBlueprint.md)
 - [ScrubResult](rapidata/api_client/docs/ScrubResult.md)
 - [ScrubTruth](rapidata/api_client/docs/ScrubTruth.md)
 - [SendCompletionMailStepModel](rapidata/api_client/docs/SendCompletionMailStepModel.md)
 - [Shape](rapidata/api_client/docs/Shape.md)
 - [ShufflingSelection](rapidata/api_client/docs/ShufflingSelection.md)
 - [SimpleWorkflowConfig](rapidata/api_client/docs/SimpleWorkflowConfig.md)
 - [SimpleWorkflowConfigModel](rapidata/api_client/docs/SimpleWorkflowConfigModel.md)
 - [SimpleWorkflowConfigModelBlueprint](rapidata/api_client/docs/SimpleWorkflowConfigModelBlueprint.md)
 - [SimpleWorkflowModel](rapidata/api_client/docs/SimpleWorkflowModel.md)
 - [SimpleWorkflowModel1](rapidata/api_client/docs/SimpleWorkflowModel1.md)
 - [SimpleWorkflowModelBlueprint](rapidata/api_client/docs/SimpleWorkflowModelBlueprint.md)
 - [SkipResult](rapidata/api_client/docs/SkipResult.md)
 - [SkipTruth](rapidata/api_client/docs/SkipTruth.md)
 - [SortCriterion](rapidata/api_client/docs/SortCriterion.md)
 - [SortDirection](rapidata/api_client/docs/SortDirection.md)
 - [SourceUrlMetadata](rapidata/api_client/docs/SourceUrlMetadata.md)
 - [SourceUrlMetadataModel](rapidata/api_client/docs/SourceUrlMetadataModel.md)
 - [StandingByLeaderboard](rapidata/api_client/docs/StandingByLeaderboard.md)
 - [StandingByLeaderboardPagedResult](rapidata/api_client/docs/StandingByLeaderboardPagedResult.md)
 - [StandingStatus](rapidata/api_client/docs/StandingStatus.md)
 - [StaticSelection](rapidata/api_client/docs/StaticSelection.md)
 - [StickyState](rapidata/api_client/docs/StickyState.md)
 - [StreamFileWrapper](rapidata/api_client/docs/StreamFileWrapper.md)
 - [StreamsMetadata](rapidata/api_client/docs/StreamsMetadata.md)
 - [StreamsMetadataModel](rapidata/api_client/docs/StreamsMetadataModel.md)
 - [SubmitCocoModel](rapidata/api_client/docs/SubmitCocoModel.md)
 - [SubmitCocoResult](rapidata/api_client/docs/SubmitCocoResult.md)
 - [SubmitParticipantResult](rapidata/api_client/docs/SubmitParticipantResult.md)
 - [SubmitPromptModel](rapidata/api_client/docs/SubmitPromptModel.md)
 - [SubmitPromptModelPromptAsset](rapidata/api_client/docs/SubmitPromptModelPromptAsset.md)
 - [TextAsset](rapidata/api_client/docs/TextAsset.md)
 - [TextAssetInput](rapidata/api_client/docs/TextAssetInput.md)
 - [TextAssetModel](rapidata/api_client/docs/TextAssetModel.md)
 - [TextMetadata](rapidata/api_client/docs/TextMetadata.md)
 - [TextMetadataModel](rapidata/api_client/docs/TextMetadataModel.md)
 - [TranscriptionMetadata](rapidata/api_client/docs/TranscriptionMetadata.md)
 - [TranscriptionMetadataInput](rapidata/api_client/docs/TranscriptionMetadataInput.md)
 - [TranscriptionMetadataModel](rapidata/api_client/docs/TranscriptionMetadataModel.md)
 - [TranscriptionPayload](rapidata/api_client/docs/TranscriptionPayload.md)
 - [TranscriptionRapidBlueprint](rapidata/api_client/docs/TranscriptionRapidBlueprint.md)
 - [TranscriptionResult](rapidata/api_client/docs/TranscriptionResult.md)
 - [TranscriptionTruth](rapidata/api_client/docs/TranscriptionTruth.md)
 - [TranscriptionWord](rapidata/api_client/docs/TranscriptionWord.md)
 - [TranslatedPromptMetadataModel](rapidata/api_client/docs/TranslatedPromptMetadataModel.md)
 - [TranslatedString](rapidata/api_client/docs/TranslatedString.md)
 - [UnlockOrderResult](rapidata/api_client/docs/UnlockOrderResult.md)
 - [UpdateBenchmarkNameModel](rapidata/api_client/docs/UpdateBenchmarkNameModel.md)
 - [UpdateCampaignModel](rapidata/api_client/docs/UpdateCampaignModel.md)
 - [UpdateDatasetNameModel](rapidata/api_client/docs/UpdateDatasetNameModel.md)
 - [UpdateDimensionsModel](rapidata/api_client/docs/UpdateDimensionsModel.md)
 - [UpdateLeaderboardNameModel](rapidata/api_client/docs/UpdateLeaderboardNameModel.md)
 - [UpdateOrderNameModel](rapidata/api_client/docs/UpdateOrderNameModel.md)
 - [UpdateValidationRapidModel](rapidata/api_client/docs/UpdateValidationRapidModel.md)
 - [UpdateValidationRapidModelTruth](rapidata/api_client/docs/UpdateValidationRapidModelTruth.md)
 - [UploadCocoResult](rapidata/api_client/docs/UploadCocoResult.md)
 - [UploadFromS3Result](rapidata/api_client/docs/UploadFromS3Result.md)
 - [UrlAssetInput](rapidata/api_client/docs/UrlAssetInput.md)
 - [UserScoreUserFilterModel](rapidata/api_client/docs/UserScoreUserFilterModel.md)
 - [ValidationChance](rapidata/api_client/docs/ValidationChance.md)
 - [ValidationSelection](rapidata/api_client/docs/ValidationSelection.md)
 - [ValidationSetModel](rapidata/api_client/docs/ValidationSetModel.md)
 - [ValidationSetModelPagedResult](rapidata/api_client/docs/ValidationSetModelPagedResult.md)
 - [ValidationSetOverviewModel](rapidata/api_client/docs/ValidationSetOverviewModel.md)
 - [ValidationSetZipPostRequestBlueprint](rapidata/api_client/docs/ValidationSetZipPostRequestBlueprint.md)
 - [VideoDurationMetadata](rapidata/api_client/docs/VideoDurationMetadata.md)
 - [VideoDurationMetadataModel](rapidata/api_client/docs/VideoDurationMetadataModel.md)
 - [WorkflowAggregationStepModel](rapidata/api_client/docs/WorkflowAggregationStepModel.md)
 - [WorkflowArtifactModel](rapidata/api_client/docs/WorkflowArtifactModel.md)
 - [WorkflowConfigArtifactModel](rapidata/api_client/docs/WorkflowConfigArtifactModel.md)
 - [WorkflowConfigArtifactModelWorkflowConfig](rapidata/api_client/docs/WorkflowConfigArtifactModelWorkflowConfig.md)
 - [WorkflowLabelingStepModel](rapidata/api_client/docs/WorkflowLabelingStepModel.md)
 - [WorkflowSplitModel](rapidata/api_client/docs/WorkflowSplitModel.md)
 - [WorkflowSplitModelFilterConfigsInner](rapidata/api_client/docs/WorkflowSplitModelFilterConfigsInner.md)
 - [WorkflowState](rapidata/api_client/docs/WorkflowState.md)
 - [ZipEntryFileWrapper](rapidata/api_client/docs/ZipEntryFileWrapper.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="bearer"></a>
### bearer

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header

<a id="oauth2"></a>
### oauth2



## Author




